# Deep Draken

Deep Draken aims to provide a framework for developing Deep Learning Models in Image Domain. It currently supports Pytorch and have implementations for image generation algorithems like:
* GAN
* CGAN
* WGAN
* WGANGP

# Installation

**1. Basic Installation**

You can install DeepDraken's latest release by using [pip](https://github.com/pypa/pip).
The command is as follows:

```
    pip3 install deepdraken
```

The experimental features have tensorflow dependencies and needs to be installed seperately.
```
pip install tensorflow>=2.0.0
pip install tensorflow-hub==0.12.0
```
**2. Installation from Source**

If you plan to be using more advanced features that currently not available in the python library, you need to install a DeepDraken from github.
The following command will install the latest version of DeepDraken from the main branch.

```
git clone https://github.com/DevavratSinghBisht/deepdraken.git
pip install --upgrade pip
cd deepdraken
pip install ./
```

**3. Learn More**

You can find out more about our PyPi package on our [PyPi page](https://pypi.org/project/deepdraken/). 

# Tutorials
Tutorials will be added soon.
<!-- #TODO add tutorials here -->